import * as _dopt_ai_javascript_client_dist_api from '@dopt/ai-javascript-client/dist/api';
import * as _dopt_ai_javascript_client_dist_core from '@dopt/ai-javascript-client/dist/core';
import * as _dopt_ai_javascript_client_dist_api_resources_assistant from '@dopt/ai-javascript-client/dist/api/resources/assistant';
import { LoggerProps } from '@dopt/logger';
import { DocumentContext, ElementContext, SemanticContext, VisualContext, AssistantQueryParams, AssistantCompletionsRequestBody, AssistantSearchRequestBody } from '@dopt/ai-assistant-definition';

interface AssistantContextProps {
    document?: DocumentContext['value'];
    element?: Element | ElementContext['value'];
    semantic?: SemanticContext['value'];
    visual?: boolean | VisualContext['value'];
}
declare function formAssistantContext({ document, element, semantic, visual, }: AssistantContextProps): Promise<{
    document?: {
        type: "document";
        value: {
            url: string;
            title: string;
            width: number;
            height: number;
        };
    } | undefined;
    element?: {
        type: "element";
        value: {
            position: {
                top: number;
                left: number;
            };
            content: string;
            tag: string;
        };
    } | undefined;
    semantic?: {
        type: "semantic";
        value: {
            semanticContent: string;
            neighboringSemanticContent: string;
        };
    } | undefined;
    visual?: {
        type: "visual";
        value: string;
    } | undefined;
}>;

interface Properties {
    /**
     * The userId you're requesting completions on behalf of.
     */
    userId: string | undefined;
    /**
     * An optional groupId for that userId.
     */
    groupId?: string | undefined;
    /**
     * Your AI API key.
     */
    apiKey: string;
    environment?: string;
    /**
     * The underlying model you want answers generated with.
     * Defaults to `gemini` if undefined.
     * Can be `gemini` or `gpt`.
     */
    model?: AssistantQueryParams['model'];
    logLevel?: LoggerProps['logLevel'];
}
declare class Assistant {
    private apiKey;
    private userId?;
    private groupId?;
    private environment;
    private model;
    private logger;
    private client;
    constructor({ apiKey, userId, groupId, environment, model, logLevel, }: Properties);
    configure(config: Partial<Pick<Properties, 'userId'>>): void;
    completions(sid: string, { query, context, }: {
        query: AssistantCompletionsRequestBody['query'];
        context: AssistantContextProps;
    }): Promise<_dopt_ai_javascript_client_dist_core.Stream<_dopt_ai_javascript_client_dist_api_resources_assistant.CompletionsStreamResponse>>;
    search(sid: string, { query, context, }: {
        query: AssistantSearchRequestBody['query'];
        context: AssistantContextProps;
    }): Promise<_dopt_ai_javascript_client_dist_api.SearchResponseItem[]>;
}

export { Assistant, type AssistantContextProps, type Properties, formAssistantContext };
